"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vscode_jsonrpc_1 = require("vscode-jsonrpc");
const vscode_languageclient_1 = require("vscode-languageclient");
/**
 * vs-code plugin API implementation
 * this is the main entry point for the vs studio code extension API
 * see https://code.visualstudio.com/docs/extensionAPI/activation-events
 */
async function activate(context) {
    const serverModule = require.resolve('./lib/server');
    const debugOptions = { execArgv: ['--inspect'] }; // Turn on debugging messages in output
    const serverOptions = {
        run: { module: serverModule, transport: vscode_languageclient_1.TransportKind.ipc },
        debug: { module: serverModule, transport: vscode_languageclient_1.TransportKind.ipc, options: debugOptions, runtime: 'node' }
    };
    const clientOptions = {
        documentSelector: [{ language: 'stylable', scheme: 'file' }],
        diagnosticCollectionName: 'stylable'
    };
    const client = new vscode_languageclient_1.LanguageClient('stylable', serverOptions, clientOptions);
    client.trace = vscode_jsonrpc_1.Trace.Messages; // Elevated debugging message info in output
    context.subscriptions.push(client.start());
    await client.onReady();
    // const files = await workspace.findFiles('**/*.st.css');
    // await Promise.all(files.map((file: any) => workspace.openTextDocument(file.fsPath)));
    return client;
}
exports.activate = activate;
/**
 * vs-code plugin API implementation
 * deactivation cleanup
 */
async function deactivate() {
    /**/
}
exports.deactivate = deactivate;
//# sourceMappingURL=extension.js.map