import postcss from 'postcss';
import { CSSResolve, SRule, Stylable, StylableMeta, ResolvedElement } from '@stylable/core';
import { CursorPosition } from './utils/selector-analyzer';
import { Completion } from './completion-types';
import { ExtendedTsLanguageService } from './types';
import { IFileSystem } from '@file-services/types';
export interface ProviderOptions {
    meta: StylableMeta;
    fs: IFileSystem;
    stylable: Stylable;
    src: string;
    tsLangService: ExtendedTsLanguageService;
    resolvedElements: ResolvedElement[][];
    parentSelector: SRule | null;
    astAtCursor: postcss.NodeBase;
    lineChunkAtCursor: string;
    lastSelectoid: string;
    fullLineText: string;
    position: ProviderPosition;
    resolved: CSSResolve[];
    currentSelector: string;
    target: CursorPosition;
    isMediaQuery: boolean;
    fakes: postcss.Rule[];
}
export interface CompletionProvider {
    provide(options: ProviderOptions): Completion[];
}
export declare class ProviderPosition {
    line: number;
    character: number;
    constructor(line: number, character: number);
}
export declare class ProviderRange {
    start: ProviderPosition;
    end: ProviderPosition;
    constructor(start: ProviderPosition, end: ProviderPosition);
}
export declare class ProviderLocation {
    uri: string;
    range: ProviderRange;
    constructor(uri: string, range: ProviderRange);
}
export declare function createRange(startLine: number, startPos: number, endline: number, endPos: number): ProviderRange;
export declare const ImportInternalDirectivesProvider: CompletionProvider;
export declare const RulesetInternalDirectivesProvider: CompletionProvider & {
    isSimpleSelector: (sel: string) => boolean;
};
export declare const TopLevelDirectiveProvider: CompletionProvider;
export declare const ValueDirectiveProvider: CompletionProvider & {
    isInsideValueDirective: (wholeLine: string, pos: number) => boolean;
};
export declare const GlobalCompletionProvider: CompletionProvider;
export declare const SelectorCompletionProvider: CompletionProvider;
export declare const ExtendCompletionProvider: CompletionProvider;
export declare const CssMixinCompletionProvider: CompletionProvider;
export declare const CodeMixinCompletionProvider: CompletionProvider;
export declare const FormatterCompletionProvider: CompletionProvider;
export declare const NamedCompletionProvider: CompletionProvider & {
    resolveImport: (importName: string, stylable: Stylable, meta: StylableMeta) => StylableMeta | null;
};
export declare const PseudoElementCompletionProvider: CompletionProvider;
export declare const StateTypeCompletionProvider: CompletionProvider;
export declare const StateSelectorCompletionProvider: CompletionProvider;
export declare const StateEnumCompletionProvider: CompletionProvider;
export declare const ValueCompletionProvider: CompletionProvider;
//# sourceMappingURL=completion-providers.d.ts.map