"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vscode_languageserver_protocol_1 = require("vscode-languageserver-protocol");
const lodash_1 = require("lodash");
const vscode_uri_1 = require("vscode-uri");
const core_1 = require("@stylable/core");
const completion_providers_1 = require("../completion-providers");
const provider_1 = require("../provider");
function resolveDocumentColors(stylable, cssService, document, fs) {
    const processor = stylable.fileProcessor;
    const src = document.getText();
    const filePath = vscode_uri_1.URI.parse(document.uri).fsPath;
    const res = provider_1.fixAndProcess(src, new completion_providers_1.ProviderPosition(0, 0), fs.sep === '/' ? filePath.replace(/\\/g, '/') : filePath);
    const meta = res.processed.meta;
    const colorComps = [];
    if (meta) {
        const lines = src.split('\n');
        lines.forEach((line, ind) => {
            const valueRegex = /value\(([\w-]+)\)/g;
            let regexResult;
            while ((regexResult = valueRegex.exec(line)) !== null) {
                const result = regexResult[1];
                const sym = meta.mappedSymbols[result];
                let color = null;
                if (sym && sym._kind === 'var') {
                    const doc = vscode_languageserver_protocol_1.TextDocument.create('', 'css', 0, '.gaga {border: ' + core_1.evalDeclarationValue(stylable.resolver, sym.text, meta, sym.node) + '}');
                    color = cssService.findColor(doc);
                }
                else if (sym && sym._kind === 'import' && sym.type === 'named') {
                    const impMeta = processor.process(sym.import.from);
                    const relevantVar = impMeta.vars.find(v => v.name === sym.name);
                    if (relevantVar) {
                        const doc = vscode_languageserver_protocol_1.TextDocument.create('', 'css', 0, '.gaga {border: ' +
                            core_1.evalDeclarationValue(stylable.resolver, 'value(' + sym.name + ')', impMeta, relevantVar.node) +
                            '}');
                        color = cssService.findColor(doc);
                    }
                }
                if (color) {
                    const range = new completion_providers_1.ProviderRange(new completion_providers_1.ProviderPosition(ind, regexResult.index + regexResult[0].indexOf(regexResult[1]) - 'value('.length), new completion_providers_1.ProviderPosition(ind, regexResult.index + regexResult[0].indexOf(regexResult[1]) + result.length));
                    colorComps.push({ color, range });
                }
            }
        });
        meta.imports.forEach(imp => {
            let impMeta;
            try {
                impMeta = processor.process(imp.from);
            }
            catch {
                /**/
            }
            if (!impMeta) {
                return;
            }
            const vars = impMeta.vars;
            vars.forEach(v => {
                const doc = vscode_languageserver_protocol_1.TextDocument.create('', 'css', 0, '.gaga {border: ' + core_1.evalDeclarationValue(stylable.resolver, v.text, impMeta, v.node) + '}');
                const color = cssService.findColor(doc);
                if (color) {
                    meta.rawAst.walkDecls(core_1.valueMapping.named, decl => {
                        const lines = decl.value.split('\n');
                        const reg = new RegExp('\\b' + v.name + '\\b', 'g');
                        const lineIndex = lines.findIndex(l => reg.test(l));
                        if (lineIndex > -1 && lines[lineIndex].indexOf(v.name) > -1) {
                            let extraLines = 0;
                            let extraChars = 0;
                            if (decl.raws.between) {
                                extraLines = decl.raws.between.split('\n').length - 1;
                                extraChars = lodash_1.last(decl.raws.between.split('\n')).length;
                            }
                            const varStart = lineIndex // replace with value parser
                                ? lines[lineIndex].indexOf(v.name) // replace with regex
                                : extraLines
                                    ? lines[lineIndex].indexOf(v.name) + extraChars
                                    : lines[lineIndex].indexOf(v.name) +
                                        core_1.valueMapping.named.length +
                                        decl.source.start.column +
                                        extraChars -
                                        1;
                            const range = new completion_providers_1.ProviderRange(new completion_providers_1.ProviderPosition(decl.source.start.line - 1 + lineIndex + extraLines, varStart), new completion_providers_1.ProviderPosition(decl.source.start.line - 1 + lineIndex + extraLines, v.name.length + varStart));
                            colorComps.push({ color, range });
                        }
                    });
                }
            });
        });
        return colorComps.concat(cssService.findColors(document));
    }
    return [];
}
exports.resolveDocumentColors = resolveDocumentColors;
function getColorPresentation(cssService, document, params) {
    const src = document.getText();
    const res = provider_1.fixAndProcess(src, new completion_providers_1.ProviderPosition(0, 0), params.textDocument.uri);
    const meta = res.processed.meta;
    const word = src
        .split('\n')[params.range.start.line].slice(params.range.start.character, params.range.end.character);
    if (word.startsWith('value(')) {
        return [];
    }
    const wordStart = new completion_providers_1.ProviderPosition(params.range.start.line + 1, params.range.start.character + 1);
    let noPicker = false;
    meta.rawAst.walkDecls(core_1.valueMapping.named, node => {
        if (node &&
            ((wordStart.line === node.source.start.line && wordStart.character >= node.source.start.column) ||
                wordStart.line > node.source.start.line) &&
            ((wordStart.line === node.source.end.line && wordStart.character <= node.source.end.column) ||
                wordStart.line < node.source.end.line)) {
            noPicker = true;
        }
    });
    if (noPicker) {
        return [];
    }
    return cssService.getColorPresentations(document, params.color, params.range);
}
exports.getColorPresentation = getColorPresentation;
//# sourceMappingURL=color-provider.js.map