import { Location, ParameterInformation, Position, SignatureHelp } from 'vscode-languageserver';
import ts from 'typescript';
import postcss from 'postcss';
import { CSSResolve, Stylable, StylableMeta } from '@stylable/core';
import { IFileSystem } from '@file-services/types';
import { ProviderPosition, ProviderRange } from './completion-providers';
import { Completion } from './completion-types';
import { ExtendedTsLanguageService } from './types';
export declare class Provider {
    private stylable;
    private tsLangService;
    private providers;
    constructor(stylable: Stylable, tsLangService: ExtendedTsLanguageService);
    provideCompletionItemsFromSrc(src: string, pos: Position, fileName: string, fs: IFileSystem): Completion[];
    getDefinitionLocation(src: string, position: ProviderPosition, filePath: string, fs: IFileSystem): Thenable<ProviderLocation[]>;
    findMyState(origMeta: StylableMeta, elementName: string, state: string): CSSResolve | null;
    getSignatureHelp(src: string, pos: Position, filePath: string, fs: IFileSystem, paramInfo: typeof ParameterInformation): SignatureHelp | null;
    private findWord;
    private escapeRegExp;
    private getSignatureForTsModifier;
    private getSignatureForJsModifier;
    private getSignatureForStateWithParamSelector;
    private getSignatureForStateWithParamDefinition;
    private createProviderOptions;
    private dedupeComps;
}
export declare function getRenameRefs(filePath: string, pos: ProviderPosition, fs: IFileSystem, stylable: Stylable): Location[];
export declare function getRefs(filePath: string, position: ProviderPosition, fs: IFileSystem, stylable: Stylable): Location[];
export declare function createMeta(src: string, path: string): {
    meta: null;
    fakes: postcss.Rule[];
} | {
    meta: StylableMeta;
    fakes: postcss.Rule[];
};
export declare function fixAndProcess(src: string, position: ProviderPosition, filePath: string): {
    processed: {
        meta: null;
        fakes: postcss.Rule[];
    } | {
        meta: StylableMeta;
        fakes: postcss.Rule[];
    };
    currentLine: string;
    cursorLineIndex: number;
};
export declare class ProviderLocation {
    uri: string;
    range: ProviderRange;
    constructor(uri: string, range: ProviderRange);
}
export declare function extractTsSignature(filePath: string, mixin: string, isDefault: boolean, tsLangService: ExtendedTsLanguageService): ts.Signature | undefined;
export declare function extractJsModifierReturnType(mixin: string, fileSrc: string): string;
export declare function isDirective(line: string): boolean;
export declare function isInValue(lineText: string, position: ProviderPosition): boolean;
export declare function getNamedValues(src: string, lineIndex: number): {
    isNamedValueLine: boolean;
    namedValues: string[];
};
export declare function getExistingNames(lineText: string, position: ProviderPosition): {
    names: string[];
    lastName: string;
};
export declare function getDefSymbol(src: string, position: ProviderPosition, filePath: string, stylable: Stylable): {
    word: string;
    meta: StylableMeta | null;
};
//# sourceMappingURL=provider.d.ts.map