"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const vscode_languageserver_1 = require("vscode-languageserver");
const node_1 = tslib_1.__importDefault(require("@file-services/node"));
const capabilities_1 = require("../capabilities");
const service_1 = require("./service");
const connection = vscode_languageserver_1.createConnection(new vscode_languageserver_1.IPCMessageReader(process), new vscode_languageserver_1.IPCMessageWriter(process));
connection.listen();
connection.onInitialize(params => {
    const rootPath = params.rootPath || '';
    const stylableLSP = new service_1.StylableLanguageService({
        fs: node_1.default,
        rootPath,
        requireModule: require,
        textDocuments: new vscode_languageserver_1.TextDocuments()
    });
    connect(stylableLSP);
    return capabilities_1.initializeResult;
});
connection.onInitialized(() => {
    connection.client.register(vscode_languageserver_1.DidChangeConfigurationNotification.type, undefined);
});
function connect(stylableLSP, conn) {
    conn = conn || connection;
    const docsDispatcher = stylableLSP.getDocsDispatcher();
    docsDispatcher.listen(connection);
    docsDispatcher.onDidChangeContent(stylableLSP.diagnose(connection));
    connection.onCompletion(stylableLSP.onCompletion.bind(stylableLSP));
    connection.onDefinition(stylableLSP.onDefinition.bind(stylableLSP));
    connection.onHover(stylableLSP.onHover.bind(stylableLSP));
    connection.onReferences(stylableLSP.onReferences.bind(stylableLSP));
    connection.onDocumentColor(stylableLSP.onDocumentColor.bind(stylableLSP));
    connection.onColorPresentation(stylableLSP.onColorPresentation.bind(stylableLSP));
    connection.onRenameRequest(stylableLSP.onRenameRequest.bind(stylableLSP));
    connection.onSignatureHelp(stylableLSP.onSignatureHelp.bind(stylableLSP));
    connection.onDocumentFormatting(stylableLSP.onDocumentFormatting.bind(stylableLSP));
    connection.onDidChangeConfiguration(stylableLSP.diagnose(connection));
}
exports.connect = connect;
//# sourceMappingURL=server.js.map