import { CompletionParams } from 'vscode-languageclient';
import { Definition, Hover, ReferenceParams, SignatureHelp, TextDocumentPositionParams, WorkspaceEdit, DocumentColorParams, ColorPresentationParams, RenameParams } from 'vscode-languageserver-protocol';
import { IConnection, TextDocuments } from 'vscode-languageserver';
import { CompletionItem, Location, ParameterInformation, Diagnostic, Position, TextDocument } from 'vscode-languageserver-types';
import { Stylable } from '@stylable/core';
import { IFileSystem } from '@file-services/types';
import { ProviderPosition } from './completion-providers';
import { Completion } from './completion-types';
interface Config {
    rootPath: string;
    fs: IFileSystem;
    requireModule: (request: string) => any;
    textDocuments: TextDocuments;
}
export declare class StylableLanguageService {
    private docsDispatcher;
    private tsLanguageService;
    private stylable;
    private provider;
    private cssService;
    private fs;
    constructor({ rootPath, fs, requireModule, textDocuments }: Config);
    getDocsDispatcher(): TextDocuments;
    getStylable(): Stylable;
    getFs(): IFileSystem;
    provideCompletionItemsFromSrc(src: string, pos: Position, fileName: string): Completion[];
    getDefinitionLocation(src: string, position: ProviderPosition, filePath: string): Promise<Location[]>;
    getSignatureHelp(src: string, pos: Position, filePath: string, paramInfo: typeof ParameterInformation): SignatureHelp | null;
    getRefs(filePath: string, position: ProviderPosition): import("vscode-languageclient").Location[];
    resolveDocumentColors(document: TextDocument): import("vscode-languageserver-types").ColorInformation[];
    getColorPresentation(document: TextDocument, params: ColorPresentationParams): import("vscode-languageserver-types").ColorPresentation[];
    diagnose(connection: IConnection): () => Promise<Diagnostic[]>;
    onCompletion(params: CompletionParams): CompletionItem[];
    onDefinition(params: TextDocumentPositionParams): Promise<Definition>;
    onHover(params: TextDocumentPositionParams): Hover | null;
    onReferences(params: ReferenceParams): Location[];
    onDocumentColor(params: DocumentColorParams): import("vscode-languageserver-types").ColorInformation[];
    onColorPresentation(params: ColorPresentationParams): import("vscode-languageserver-types").ColorPresentation[];
    onRenameRequest(params: RenameParams): WorkspaceEdit;
    onSignatureHelp(params: TextDocumentPositionParams): Thenable<SignatureHelp> | null;
    onDocumentFormatting(): null;
}
export {};
//# sourceMappingURL=service.d.ts.map